Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12)

Unified Diff: tools/git_clone_to_google3.sh

Issue 1295213002: Revert of Fix a few bugs in the google3 sync scripts. (Closed) Base URL: https://skia.googlesource.com/skia@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tools/sync_google3.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/git_clone_to_google3.sh
diff --git a/tools/git_clone_to_google3.sh b/tools/git_clone_to_google3.sh
index 38d79e3c01cf4030b1b0432ea9d14c8dad87500a..1e2f34f82dbcec546c928d9601775e484f64ba2c 100755
--- a/tools/git_clone_to_google3.sh
+++ b/tools/git_clone_to_google3.sh
@@ -12,7 +12,6 @@
source gbash.sh || exit
DEFINE_string skia_rev "" "Git hash of Skia revision to clone, default LKGR."
-gbash::init_google "$@"
set -x -e
@@ -49,8 +48,8 @@
--include=/dm \
--include=/gm \
--include=/include \
+ --include=/src \
--exclude=/src/animator \
- --include=/src \
--include=/tests \
--include=/third_party \
--include=/tools \
@@ -81,16 +80,11 @@
g4 revert README.google
g4 revert BUILD
# Use google3 version of OWNERS.
find . \
- -name OWNERS \
+ \( -name OWNERS -o -name README.google -o -name BUILD \) \
-exec git update-index --skip-worktree \{\} \; \
-execdir g4 revert \{\} \;
-
-# Tell git to ignore these files that have Windows line endings, because Piper
-# will always change them to Unix line endings.
-git update-index --skip-worktree make.bat
-git update-index --skip-worktree make.py
# Tell git to ignore files left out of the rsync (i.e. "deleted" files).
git status --porcelain | \
« no previous file with comments | « no previous file | tools/sync_google3.sh » ('j') | no next file with comments »
@@ -81,16 +80,11 @@
g4 revert README.google
g4 revert BUILD
-# Use google3 version of OWNERS.
+# Use google3 version of OWNERS, README.google, and BUILD.
find . \

Powered by Google App Engine
This is Rietveld 408576698